@@ -104,8 +104,11 @@ class ChoiceValue(DataVarsSerializer):
             if not readOnly:
                 self.values, self.comments = self.getChoice(varObj)
             elif isinstance(varObj, SourceReadonlyVariable):
-                self.values, self.comments = \
-                    zip(*varObj.getMapHumanReadable().items())
+                items = varObj.getMapHumanReadable().items()
+                if items:
+                    self.values, self.comments = zip(*items)
+                else:
+                    self.values, self.comments = [],[]
                 self.values = self.arrayString(self.values)
                 self.comments = self.arrayString(self.comments)
             if varObj.mode == 'w':
